==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/Input/flac/translations/flac_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="62"/>
        <source>FLAC Files</source>
        <translation>FLAC 檔案</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="203"/>
        <source>About FLAC Audio Plugin</source>
        <translation>關於 FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="204"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="205"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="80"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/flac/translations/flac_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="61"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 外掛</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="63"/>
        <source>FLAC Files</source>
        <translation>FLAC 檔案</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="204"/>
        <source>About FLAC Audio Plugin</source>
        <translation>關於 FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="205"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="206"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="94"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="95"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="95"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="96"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="96"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
